local tf = love.math.newTransform()

-- Apply our transformation
tf:scale(5)
tf:rotate(25)
tf:translate(10, 10)

-- Find the mouse position in transformed coordinates
local aimX, aimY = tf:inverseTransformPoint(love.mouse.getPosition())

function love.mousemoved(x, y)
  -- Keep aimX, aimY up-to-date with the cursor movement
  aimX, aimY = tf:inverseTransformPoint(x, y)
end

function love.draw()
  -- Set the transform before drawing
  love.graphics.replaceTransform(tf)

  -- Drawn circle parameters
  local posX, posY = 30, 30
  local R = 20

  -- Find the vector pointing to the mouse
  local vx = aimX - posX
  local vy = aimY - posY

  love.graphics.setLineWidth(0.5)

  -- Draw grid
  for i = -199, 199, 20 do
    love.graphics.line(i, -199, i, love.graphics.getHeight())
  end
  for i = -199, 199, 20 do
    love.graphics.line(-199, i, love.graphics.getWidth(), i)
  end

  love.graphics.circle("line", posX, posY, R)

  -- Set the length of the vector to the radius of the circle
  local len = math.sqrt(vx*vx + vy*vy)
  if len > 0 then
    -- Adjust vector
    vx = vx * R / len
    vy = vy * R / len
    -- Draw the line unless the mouse is at the centre of the circle
    love.graphics.line(posX, posY,  -- from centre of circle...
      posX + vx, posY + vy)         -- in the direction of the vector
  end
end

function love.update(dt)
  -- Allow key movement: cursor keys to displace, keypad +/- to zoom
  local pressed = love.keyboard.isScancodeDown
  if pressed("escape") then return love.event.quit() end
  if pressed("left") then tf:translate(dt*10, 0) end
  if pressed("right") then tf:translate(dt*-10, 0) end
  if pressed("up") then tf:translate(0, dt*-10) end
  if pressed("down") then tf:translate(0, dt*10) end
  if pressed("kp+") then tf:scale(1.5^dt) end
  if pressed("kp-") then tf:scale(1.5^-dt) end
end
